# PyPaDS-Onto

[![Documentation Status](https://readthedocs.org/projects/pypads-onto/badge/?version=latest)](https://pypads.readthedocs.io/projects/pypads-onto/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/pypads-onto.svg)](https://badge.fury.io/py/pypads-onto)  

<!--- ![Build status](https://gitlab.padim.fim.uni-passau.de/RP-17-PaDReP/ontopads/badges/master/pipeline.svg) --->

This is the Ontology extension to pypads framework. It will be used for semantic harmonization.